@@ -56,10 +56,10 @@ class UserState(metaclass=abc.ABCMeta):
     @command
     async def PING(self, token):
         host = aioircd.servlocal.get().host
-        await self.user.send(f"PONG {host} {token}", log=logger.isEnabledFor(logging.DEBUG))
+        await self.user.send(f":{host} PONG {host} {token}", log=logger.isEnabledFor(logging.DEBUG))
 
     @command
-    async def PONG(self, token):
+    async def PONG(self, token=None):
         pass  # ignored
 
     @command
@@ -107,9 +107,6 @@ class UserState(metaclass=abc.ABCMeta):
         self.user.channels.clear()
         self.user.state = QuitState(self.user)
 
-        if type(self) not in (PasswordState, ConnectedState):
-            servlocal.users.pop(self.user.nick)
-
 
 class PasswordState(UserState):
     @command
@@ -161,6 +158,7 @@ class ConnectedState(UserState):
     async def register(self):
         servlocal = aioircd.servlocal.get()
         self.user.state = RegisteredState(self.user)
+        aioircd.update_status()
         await self.user.send(textwrap.dedent("""\
             :{host} 001 {nick} :Welcome to the Internet Relay Network {nick}
             :{host} 002 {nick} :Your host is {host}, running version {version}
@@ -227,6 +225,7 @@ class RegisteredState(UserState):
             if not chan:
                 chan = Channel(channel)
                 servlocal.channels[chan.name] = chan
+                aioircd.update_status()
             chan.users.add(self.user)
             self.user.channels.add(chan)
 
@@ -254,6 +253,7 @@ class RegisteredState(UserState):
             chan.users.remove(self.user)
             if not chan.users:
                 servlocal.channels.pop(chan.name)
+                aioircd.update_status()
 
             if reason:
                 await chan.send(f":{self.user.nick} PART {channel} :{reason}")
@@ -316,6 +316,10 @@ class RegisteredState(UserState):
 
 class QuitState(UserState):
     """ The user sent the QUIT command, no more message should be processed """
+    def __init__(self, user):
+        super().__init__(user)
+        user.nick = None
+        aioircd.update_status()
 
     @command
     async def PING(self, server1=None, server2=None):
